@@ -1,8 +1,8 @@
 module Network.Socket.Handle where
 
-import qualified GHC.IO.Device (IODeviceType(Stream))
+import qualified GHC.IO.Device (IODeviceType (Stream))
 import GHC.IO.Handle.FD (fdToHandle')
-import System.IO (IOMode(..), Handle, BufferMode(..), hSetBuffering)
+import System.IO (BufferMode (..), Handle, IOMode (..), hSetBuffering)
 
 import Network.Socket.Types
 
@@ -15,14 +15,13 @@ import Network.Socket.Types
 -- close the 'Socket' after 'socketToHandle', call 'System.IO.hClose'
 -- on the 'Handle'.
 --
--- Caveat 'Handle' is not recommended for network programming in 
+-- Caveat 'Handle' is not recommended for network programming in
 -- Haskell, e.g. merely performing 'hClose' on a TCP socket won't
 -- cooperate with peer's 'gracefulClose', i.e. proper shutdown
 -- sequence with appropriate handshakes specified by the protocol.
-
 socketToHandle :: Socket -> IOMode -> IO Handle
 socketToHandle s mode = invalidateSocket s err $ \oldfd -> do
-    h <- fdToHandle' oldfd (Just GHC.IO.Device.Stream) True (show s) mode True{-bin-}
+    h <- fdToHandle' oldfd (Just GHC.IO.Device.Stream) True (show s) mode True {-bin-}
     hSetBuffering h NoBuffering
     return h
   where
