@@ -11,6 +11,7 @@ import System.IO.Error (catchIOError)
 #endif
 
 #if defined(mingw32_HOST_OS)
+import Control.Exception (bracket)
 import Foreign (FunPtr)
 import GHC.Conc (asyncDoProc)
 #else
@@ -63,8 +64,9 @@ import Network.Socket.Types
 -- can be handled with one socket.
 --
 -- >>> import Network.Socket
+-- >>> import qualified Data.List.NonEmpty as NE
 -- >>> let hints = defaultHints { addrFlags = [AI_NUMERICHOST, AI_NUMERICSERV], addrSocketType = Stream }
--- >>> addr:_ <- getAddrInfo (Just hints) (Just "127.0.0.1") (Just "5000")
+-- >>> addr <- NE.head <$> getAddrInfo (Just hints) (Just "127.0.0.1") (Just "5000")
 -- >>> sock <- socket (addrFamily addr) (addrSocketType addr) (addrProtocol addr)
 -- >>> Network.Socket.bind sock (addrAddress addr)
 -- >>> getSocketName sock
@@ -81,6 +83,7 @@ socket family stype protocol = E.bracketOnError create c_close $ \fd -> do
     -- This socket is not managed by the IO manager yet.
     -- So, we don't have to call "close" which uses "closeFdWith".
     unsetIPv6Only s
+    setDontFragment s
     return s
   where
     create = do
@@ -118,6 +121,15 @@ socket family stype protocol = E.bracketOnError create c_close $ \fd -> do
     unsetIPv6Only _ = return ()
 #endif
 
+    setDontFragment s = when (family == AF_INET) $
+#if HAVE_DECL_IP_DONTFRAG || HAVE_DECL_IP_MTU_DISCOVER
+      setSocketOption s DontFragment 1
+#else
+      -- do nothing
+      return ()
+#endif
+
+
 -----------------------------------------------------------------------------
 -- Binding a socket
 
@@ -191,7 +203,7 @@ listen s backlog = withFdSocket s $ \fd -> do
 accept :: SocketAddress sa => Socket -> IO (Socket, sa)
 accept listing_sock = withNewSocketAddress $ \new_sa sz ->
     withFdSocket listing_sock $ \listing_fd -> do
- new_sock <- callAccept listing_fd new_sa sz >>= mkSocket
+ new_sock <- E.bracketOnError (callAccept listing_fd new_sa sz) c_close mkSocket
  new_addr <- peekSocketAddress new_sa
  return (new_sock, new_addr)
   where
@@ -201,13 +213,12 @@ accept listing_sock = withNewSocketAddress $ \new_sa sz ->
                        throwSocketErrorIfMinus1Retry "Network.Socket.accept" $
                          c_accept_safe fd sa ptr_len
        | otherwise = do
-             paramData <- c_newAcceptParams fd (fromIntegral sz) sa
-             rc        <- asyncDoProc c_acceptDoProc paramData
-             new_fd    <- c_acceptNewSock paramData
-             c_free paramData
-             when (rc /= 0) $
-               throwSocketErrorCode "Network.Socket.accept" (fromIntegral rc)
-             return new_fd
+             bracket (c_newAcceptParams fd (fromIntegral sz) sa) c_free $ \paramData -> do
+                 rc     <- asyncDoProc c_acceptDoProc paramData
+                 new_fd <- c_acceptNewSock paramData
+                 when (rc /= 0) $
+                     throwSocketErrorCode "Network.Socket.accept" (fromIntegral rc)
+                 return new_fd
 #else
      callAccept fd sa sz = with (fromIntegral sz) $ \ ptr_len -> do
 # ifdef HAVE_ADVANCED_SOCKET_FLAGS
