@@ -14,6 +14,7 @@ import Network.Test.Common
 import System.Mem (performGC)
 import System.IO.Error (tryIOError)
 import System.IO.Temp (withSystemTempDirectory)
+import System.Posix.Types (Fd(..))
 import Foreign.C.Types ()
 
 import Test.Hspec
@@ -117,7 +118,7 @@ spec = do
 
         it "does not cause segfault on macOS 10.8.2 due to AI_NUMERICSERV" $ do
             let hints = defaultHints { addrFlags = [AI_NUMERICSERV] }
-            void $ getAddrInfo (Just hints) (Just "localhost") Nothing
+            void (getAddrInfo (Just hints) (Just "localhost") Nothing :: IO [AddrInfo])
 
 #if defined(mingw32_HOST_OS)
     let lpdevname = "loopback_0"
@@ -378,6 +379,12 @@ spec = do
             let msgid = CmsgId (-300) (-300) in
             show msgid `shouldBe` "CmsgId (-300) (-300)"
 
+#if !defined(_WIN32)
+    describe "bijective encodeCmsg-decodeCmsg roundtrip equality" $ do
+        it "holds for [Fd]" $ forAll genFds $
+            \x -> (decodeCmsg . encodeCmsg $ x) == Just (x :: [Fd])
+#endif
+
     describe "bijective read-show roundtrip equality" $ do
         it "holds for Family" $ forAll familyGen $
             \x -> (read . show $ x) == (x :: Family)
@@ -415,6 +422,9 @@ sockoptGen = biasedGen (\g -> SockOpt <$> g <*> g) sockoptPatterns arbitrary
 cmsgidGen :: Gen CmsgId
 cmsgidGen = biasedGen (\g -> CmsgId <$> g <*> g) cmsgidPatterns arbitrary
 
+genFds :: Gen [Fd]
+genFds = listOf (Fd <$> arbitrary)
+
 -- pruned lists of pattern synonym values for each type to generate values from
 
 familyPatterns :: [Family]
@@ -446,11 +456,11 @@ sockoptPatterns :: [SocketOption]
 sockoptPatterns = nub
     [UnsupportedSocketOption
     ,Debug,ReuseAddr,SoDomain,Type,SoProtocol,SoError,DontRoute
-    ,Broadcast,SendBuffer,RecvBuffer,KeepAlive,OOBInline,TimeToLive
-    ,MaxSegment,NoDelay,Cork,Linger,ReusePort
+    ,Broadcast,SendBuffer,RecvBuffer,KeepAlive,KeepInit,OOBInline
+    ,TimeToLive,MaxSegment,NoDelay,Cork,Linger,ReusePort
     ,RecvLowWater,SendLowWater,RecvTimeOut,SendTimeOut
     ,UseLoopBack,UserTimeout,IPv6Only
-    ,RecvIPv4TTL,RecvIPv4TOS,RecvIPv4PktInfo
+    ,RecvIPv4TTL,RecvIPv4TOS,RecvIPv4PktInfo,DontFragment
     ,RecvIPv6HopLimit,RecvIPv6TClass,RecvIPv6PktInfo]
 
 cmsgidPatterns :: [CmsgId]
@@ -462,5 +472,5 @@ cmsgidPatterns = nub
     , CmsgIdIPv6TClass
     , CmsgIdIPv4PktInfo
     , CmsgIdIPv6PktInfo
-    , CmsgIdFd
+    , CmsgIdFds
     ]
